Examples
========

To run any of the examples copy the contents of ``database.cfg.example`` into
a new file called ``database.cfg`` and adjust the settings to your needs.

Then run one of the following examples:

- ``callback_client.py``
- ``adisp_client.py``
- ``blocking_client.py``
- ``gen_example.py``
- ``swift_example.py`` (you need to install Swift_ first)


.. _Swift: http://code.naeseth.com/swirl/
